@@ -9,25 +9,46 @@ from collections import namedtuple
 
 UserFolders = namedtuple("UserFolders", ("home", "desktop", "startmenu"))
 
-platform = sys.platform
+uname = sys.platform
 if os.name == "nt":
-    platform = "win"
-if platform == "linux2":
-    platform = "linux"
+    uname = "win"
+if uname == "linux2":
+    uname = "linux"
 
 from .linux import (scut_ext, ico_ext, make_shortcut,
                     get_folders, get_homedir, get_desktop)
 
-if platform.startswith('win'):
+if uname.startswith('win'):
     from .windows import (scut_ext, ico_ext, make_shortcut,
                           get_folders, get_homedir, get_desktop)
 
-elif platform.startswith('darwin'):
+elif uname.startswith('darwin'):
     from .darwin import (scut_ext, ico_ext, make_shortcut,
                          get_folders, get_homedir, get_desktop)
 
 from .shortcut import shortcut, Shortcut, fix_filename
 
+# for back-compat
+from . import utils
+utils.get_homedir = get_homedir
+utils.get_folders = get_folders
+utils.platform = platform = uname
+
+def get_cwd():
+    """get current working directory
+    Note: os.getcwd() can fail with permission error.
+
+    when that happens, this changes to the users `HOME` directory
+    and returns that directory so that it always returns an existing
+    and readable directory.
+    """
+    try:
+        return os.getcwd()
+    except:
+        home = get_homedir()
+        os.chdir(home)
+        return home
+
 try:
     import wx
     HAS_WX = True
@@ -36,13 +57,6 @@ except ImportError:
     HAS_WX = False
 
 
-# for back-compat
-from . import utils
-utils.get_homedir = get_homedir
-utils.get_folders = get_folders
-utils.platform = platform
-
-
 def shortcut_cli():
     '''
     command-line interface to creating desktop shortcuts
@@ -102,7 +116,7 @@ def shortcut_cli():
 
     if args.bootstrap:
         bindir = 'bin'
-        if platform.startswith('win'):
+        if uname.startswith('win'):
             bindir = 'Scripts'
         here, this = os.path.split(os.path.abspath(__file__))
         icon = os.path.join(here, 'icons', 'ladder.%s' % ico_ext[0])
